@@ -3,8 +3,14 @@ use Moose;
 
 BEGIN { extends 'Catalyst::Controller' }
 
+my $Count = 1;
+
 sub root :Chained('/') PathPart('') Args(0) {
-  pop->res->body('root');
+    my ($self, $c) = @_;
+    $c->stash(
+        count => $Count++,
+    );
+    $c->res->body('root');
 }
 
 1;
